==> driza-0.5.tar.gz: driza-0.5.0/Driza/operaciones/histograma.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#graficos.py

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez
#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
from qt import *
from rpy import *
from Driza.widgets import wopciones

def funcion(dato,variable,cosa,opciones):  # Cambiar cosa por caso
	diccionario={}
	lista=[int(x) for x in self.__datos[variable]]
	import random
	nombrefichero="/tmp/driza"+random.randint(1,99999)+".png"
	diccionario["ruta"]=nombrefichero
	r.png(nombrefichero) #Directorio temporal de la config
	r.hist(lista,main=variable,nclass=int(opciones["nintervalos"]))
	r.dev_off()
	return diccionario

def initresultado(resultado,opciones):
	"""Inicializa al objeto resultado, añadiendole lo que crea conveniente"""
	resultado.addImagen("resultado")
	resultado["resultado"].titulo="Histograma"


def interfazresultado(resultado,variable,caso,diccionario):
	"""Este método dice como introducir los datos en la tabla"""
	lista=[]
	lista.append(diccionario["ruta"])
	resultado["resultado"].set(variable,caso,lista)

opciones=wopciones.WOpciones()
widget={"tipo":"Graficos","opciones":opciones}

==> driza-0.5.1.tar.gz: driza-0.5.1/Driza/operaciones/histograma.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#graficos.py

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez
#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
from qt import *
from rpy import *
from Driza.widgets import wopciones

def funcion(dato,ejes,opciones): 
	diccionario={}
	variable=ejes["EJEX"]
	lista=[float(x) for x in dato[variable]]
	import random
	nombrefichero="/tmp/driza"+str(random.randint(1,99999))+".png"
	diccionario["ruta"]=nombrefichero
	r.png(nombrefichero) #Directorio temporal de la config
	print opciones[u"NúmeroIntervalos"].__class__
	r.hist(lista,main=variable,nclass=int(opciones[u"NúmeroIntervalos"]))
	r.dev_off()
	return diccionario

def initresultado(resultado,opciones):
	"""Inicializa al objeto resultado, añadiendole lo que crea conveniente"""
	resultado.addImagen("resultado")
	resultado["resultado"].titulo="Histograma"


def interfazresultado(resultado,variable,diccionario):
	"""Este método dice como introducir los datos en la tabla"""
	resultado["resultado"].set(diccionario["ruta"])

diccionarioopciones={"nombre":u"NúmeroIntervalos","tipo":"EntradaTexto"}
diccionariograficosy={"nombre":"EJEY","tipo":"Texto","texto":"Ocurrencias del eje y"}
diccionariograficosx={"nombre":"EJEX","tipo":"Variables"}

widget={"tipo":"Graficos","opciones":[diccionarioopciones],"graficos":[diccionariograficosy,diccionariograficosx]}
